@@ -56,6 +56,11 @@ def simulate(l, b, beamwidth=0.6, v_min=-400, v_max=400, plot_file=''):
 	left_frequency_edge = 1420.4057517667 + 1420.4057517667e6 * -v_max/(299792458 * 1e6)
 	right_frequency_edge = 1420.4057517667 + 1420.4057517667e6 * -v_min/(299792458 * 1e6)
 
+	# Limit galactic coordinates to 2 decimal places
+	l = float('%.2f' % l)
+	b = float('%.2f' % b)
+
+	# Initiate plot
 	fig, ax = plt.subplots()
 
 	try:
@@ -87,6 +92,7 @@ def simulate(l, b, beamwidth=0.6, v_min=-400, v_max=400, plot_file=''):
 		# Display plot
 		plt.show()
 	plt.clf()
+	plt.close()
 
 def predict(lat, lon, height=0, source='', date='', plot_sun=True, plot_file=''):
 	from astropy.time import Time
@@ -224,7 +230,9 @@ def map_hi(ra=None, dec=None, plot_file=''):
 	import matplotlib
 	import matplotlib.pyplot as plt
 
-	plt.rcParams["figure.figsize"] = (20,20)
+	# Adjust figsize
+	if plot_file != '':
+		plt.rcParams["figure.figsize"] = (20,20)
 
 	# Get package path
 	if sys.version_info >= (3, 4):
@@ -232,7 +240,7 @@ def map_hi(ra=None, dec=None, plot_file=''):
 		virgo_path = importlib.util.find_spec('virgo').submodule_search_locations[0]
 	else:
 		import imp
-		sys.modules['virgo'].__path__[0]
+		virgo_path = sys.modules['virgo'].__path__[0]
 
 	# Load HI survey
 	survey = np.loadtxt(virgo_path+'/map.txt')
@@ -241,10 +249,7 @@ def map_hi(ra=None, dec=None, plot_file=''):
 	survey_corrected = np.flip(survey, 1)
 
 	# Plot map
-	plt.imshow(survey_corrected, extent=[24,0,-90,90], aspect=0.07, interpolation='None')
-
-	# Survey citation
-	plt.text(4.75, 91.8, 'LAB HI Survey (Kalberla et al., 2005)', fontsize=14, bbox={'facecolor': 'white', 'pad': 4})
+	plt.imshow(survey_corrected, extent=[24,0,-90,90], aspect=0.07, interpolation='gaussian')
 
 	# Plot properties
 	plt.title('All-Sky Map (21 cm)', fontsize=28, y=1.01)
@@ -257,18 +262,21 @@ def map_hi(ra=None, dec=None, plot_file=''):
 	# Plot given source position
 	if ra is not None and dec is not None:
 		if ra >= 0 and ra <= 24 and dec >= -90 and dec <= 90:
-			plt.axvline(ra, 0, 1, linestyle='--', linewidth=2, color=(214/255, 39/255, 40/255, 0.9))
-			plt.axhline(dec, 0, 1, linestyle='--', linewidth=2, color=(214/255, 39/255, 40/255, 0.9))
-			plt.scatter(ra, dec, s=350, color=[214/255, 39/255, 40/255])
+			plt.axvline(ra, 0, 1, linestyle='--', linewidth=2, color=(0.85, 0.15, 0.16, 0.9))
+			plt.axhline(dec, 0, 1, linestyle='--', linewidth=2, color=(0.85, 0.15, 0.16, 0.9))
+			plt.scatter(ra, dec, s=200, color=[0.85, 0.15, 0.16])
 		else:
 			warnings.warn('RA and/or Dec out of range. Ensure the input is decimal hours and decimal degrees respectively.')
 
-	#plt.tight_layout() ### CHECK IF NECESSARY
 	if plot_file != '':
-		# Save plot to file
-		plt.savefig(plot_file, bbox_inches='tight') ### CHECK IF NECESSARY , pad_inches=0.1)
+                # Add survey citation
+                plt.text(5.62, 92.1, 'LAB HI Survey (Kalberla et al., 2005)', fontsize=14, bbox={'facecolor': 'white', 'pad': 4})
+
+                # Save plot to file
+                plt.savefig(plot_file, bbox_inches='tight')
 	else:
 		# Display plot
+		plt.tight_layout()
 		plt.show()
 	plt.clf()
 
